================================
AnnData(Set) object manipulation
================================
.. currentmodule:: snapatac2

Backed AnnData objects
~~~~~~~~~~~~~~~~~~~~~~

.. autosummary::
    :toctree: _autosummary

    AnnData
    AnnDataSet

AnnData IO 
~~~~~~~~~~

.. autosummary::
    :toctree: _autosummary

    read
    read_mtx
    read_10x_mtx
    read_dataset
    concat
    get_write_options
    set_write_options